@@ -1,5 +1,5 @@
 # encoding=utf-8
-# Copyright (C) 2011-2012  Patrick Totzke <patricktotzke@gmail.com>
+# Copyright (C) Patrick Totzke <patricktotzke@gmail.com>
 # Copyright © 2017 Dylan Baker <dylan@pnwbakers.com>
 # This file is released under the GNU GPL, version 3 or a later revision.
 # For further details see the COPYING file
@@ -365,7 +365,7 @@ def render_part(part, field_key='copiousoutput'):
             stdin = raw_payload
 
         # read parameter, create handler command
-        parms = tuple('='.join(p) for p in part.get_params())
+        parms = tuple('='.join(p) for p in part.get_params(failobj=[]))
 
         # create and call external command
         cmd = mailcap.subst(entry['view'], ctype,
@@ -429,11 +429,7 @@ def remove_cte(part, as_string=False):
     # decoding into a str is done at the end if requested
     elif '8bit' in cte:
         logging.debug('assuming Content-Transfer-Encoding: 8bit')
-        # Python's mail library may decode 8bit as raw-unicode-escape, so
-        # we need to encode that back to bytes so we can decode it using
-        # the correct encoding, or it might not, in which case assume that
-        # the str representation we got is correct.
-        bp = payload.encode('raw-unicode-escape')
+        bp = payload.encode('utf8')
 
     elif 'quoted-printable' in cte:
         logging.debug('assuming Content-Transfer-Encoding: quoted-printable')
@@ -467,7 +463,7 @@ def remove_cte(part, as_string=False):
 MISSING_HTML_MSG = ("This message contains a text/html part that was not "
                     "rendered due to a missing mailcap entry. "
                     "Please refer to item 1 in our FAQ: "
-                    "http://alot.rtfd.io/en/latest/faq.html")
+                    "https://alot.rtfd.io/en/latest/faq.html")
 
 
 def get_body_part(mail, mimetype=None):
