@@ -1,9 +1,10 @@
-# Copyright (C) 2011-2017  Patrick Totzke <patricktotzke@gmail.com>
+# Copyright (C) Patrick Totzke <patricktotzke@gmail.com>
 # This file is released under the GNU GPL, version 3 or a later revision.
 # For further details see the COPYING file
 
 import urwid
-import re
+
+from ..utils import ansi
 
 
 class ANSIText(urwid.WidgetWrap):
@@ -78,16 +79,6 @@ def parse_escapes_to_urwid(text, default_attr=None, default_attr_focus=None,
     we interpret only SGR parameters that urwid supports (excluding true color)
     See https://en.wikipedia.org/wiki/ANSI_escape_code#CSI_sequences
     """
-
-    b1 = r'\033\['  # Control Sequence Introducer
-    b2 = r'[0-9:;<=>?]*'  # parameter bytes
-    b3 = r'[ !\"#$%&\'()*+,-./]*'  # intermediate bytes
-    b4 = r'[A-Z[\]^_`a-z{|}~]'  # final byte"
-    esc_pattern = b1 \
-        + r'(?P<pb>' + b2 + ')' \
-        + r'(?P<ib>' + b3 + ')' \
-        + r'(?P<fb>' + b4 + ')'
-
     # these two will be returned
     urwid_text = []  # we will accumulate text (with attributes) here
     # mapping from included attributes to focused attr
@@ -113,17 +104,16 @@ def parse_escapes_to_urwid(text, default_attr=None, default_attr_focus=None,
         urwid_text.append((urwid_attr, infix))
 
     def reset_attr():
+        attr.clear()
         attr.update(fg=default_attr.foreground,
                     bg=default_attr.background, bold=default_attr.bold,
                     underline=default_attr.underline,
                     standout=default_attr.underline)
 
-    def update_attr(m):
-        # parameter, intermediate, final bytes in the esc seq
-        pb, _, fb, = m.groups()
+    def update_attr(pb, _, fb):
         if fb == 'm':
             # selector bit found. this means theming changes
-            if not pb:  # no bit r zero  --> reset
+            if not pb or pb == "0":
                 reset_attr()
             elif pb.startswith('38;5;'):
                 # 8-bit colour foreground
@@ -141,14 +131,8 @@ def parse_escapes_to_urwid(text, default_attr=None, default_attr_focus=None,
                     if code in ECODES:
                         attr.update(ECODES[code])
 
-    # iterate over text
-    start = 0  # points to start of current infix
+    for pb, ib, fb, infix in ansi.parse_csi(text):
+        update_attr(pb, ib, fb)
+        append_themed_infix(infix)
 
-    for m in re.finditer(esc_pattern, text):
-        infix = text[start:m.start()]  # text beween last and this Esc seq
-        update_attr(m)
-        append_themed_infix(infix)  # add using prev attribute
-        start = m.end()  # start of next infix is after this esc sec
-
-    append_themed_infix(text[start:])  # add final infix
     return urwid_text, urwid_focus
